References
----------

.. [Wolf18] Wolf *et al.* (2018),
   *Scanpy: large-scale single-cell gene expression data analysis*,
   `Genome Biology <https://doi.org/10.1186/s13059-017-1382-0>`__.

.. [Manno18] La Manno *et al.* (2018),
   *RNA velocity of single cells*,
   `Nature <https://doi.org/10.1038/s41586-018-0414-6>`__.